@@ -46,7 +46,14 @@ class RosTable(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTable.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosTableProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -62,7 +69,9 @@ class RosTable(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTable._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -101,7 +110,9 @@ class RosTable(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -116,7 +127,11 @@ class RosTable(
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -134,7 +149,11 @@ class RosTable(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "project").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "project", value)
 
@@ -154,7 +173,11 @@ class RosTable(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "comment").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "comment", value)
 
@@ -183,7 +206,11 @@ class RosTable(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "if_not_exists").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ifNotExists", value)
 
@@ -203,7 +230,11 @@ class RosTable(
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "lifecycle").fset)
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "lifecycle", value)
 
@@ -223,7 +254,11 @@ class RosTable(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosTable.SchemaProperty"]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "schema").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosTable.SchemaProperty"]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "schema", value)
 
@@ -246,7 +281,11 @@ class RosTable(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTable, "string_schema").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "stringSchema", value)
 
@@ -269,7 +308,14 @@ class RosTable(
             :param comment: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosTable.ColumnsProperty.__init__)
+                def stub(
+                    *,
+                    name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    comment: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                 check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                 check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
@@ -338,7 +384,14 @@ class RosTable(
             :param comment: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosTable.PartitionsProperty.__init__)
+                def stub(
+                    *,
+                    name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    comment: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                 check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                 check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
@@ -405,7 +458,13 @@ class RosTable(
             :param partitions: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosTable.SchemaProperty.__init__)
+                def stub(
+                    *,
+                    columns: typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosTable.ColumnsProperty", typing.Dict[str, typing.Any]]]]],
+                    partitions: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosTable.PartitionsProperty", typing.Dict[str, typing.Any]]]]]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                 check_type(argname="argument partitions", value=partitions, expected_type=type_hints["partitions"])
             self._values: typing.Dict[str, typing.Any] = {
@@ -483,7 +542,18 @@ class RosTableProps:
         :param string_schema: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTableProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                project: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                comment: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                if_not_exists: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                lifecycle: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                schema: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosTable.SchemaProperty, typing.Dict[str, typing.Any]]]] = None,
+                string_schema: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
             check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
@@ -624,7 +694,14 @@ class Table(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Table.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["TableProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -680,7 +757,18 @@ class TableProps:
         :param string_schema: Property stringSchema: Create a table with field names and field type strings. Example: 'num bigint, num2 double', 'pt string'
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TableProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                project: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                comment: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                if_not_exists: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                lifecycle: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                schema: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosTable.SchemaProperty, typing.Dict[str, typing.Any]]]] = None,
+                string_schema: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
             check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
